## Pearl net catch efficiency analysis ###
gc()
## Load packages ####
if (!"glmmTMB" %in% rownames(installed.packages())){
    utils::install.packages("glmmTMB")
  ## You should probably accept all the updates from CRAN if asked
}
library(glmmTMB)
if (!"ggeffects" %in% rownames(installed.packages())){
  utils::install.packages("ggeffects")
  ## You should probably accept all the updates from CRAN if asked
}
library(ggeffects)

## Load trial data ####
path_to_data <- "~/pearlnet_data.csv"
dat <- read.csv(path_to_data)

## Models ####
### EM data ####
m1 <- glmmTMB(cod ~ 
                treatment +
                offset(log(n_nets)) +
                (1 | date),
              family = poisson,
              dat)
summary(m1)
m2 <- glmmTMB(cod ~ 
                treatment +
                offset(log(n_nets)) +
                (1 | date),
              family = nbinom2,
              dat)
summary(m2)
m3 <- glmmTMB(cod ~ 
                treatment +
                offset(log(n_nets)) +
                (1 | date),
              family = nbinom1,
              dat)
summary(m3)

ggpredict(m1, "treatment", condition = c(n_nets = 1))
# Predicted counts of cod
# 
# treatment | Predicted |       95% CI
#'------------------------------------
# c         |      0.30 | [0.18, 0.53]
# t         |      0.36 | [0.20, 0.65]
# 
# Adjusted for:
# *   date = NA (population-level)

### Fisher's logbook data ####
mf1 <- glmmTMB(log(catch_kg) ~
                 treatment + 
                 offset(log(n_nets)) +
                 (1 | date),
               dat)
summary(mf1)
ggpredict(mf1, "treatment", condition = c(n_nets = 1))
# # Predicted values of catch_kg
# 
# treatment | Predicted |         95% CI
#'--------------------------------------
# c         |      2.63 | [1.98, 3.49]
# t         |      2.50 | [1.88, 3.32]
# 
# Adjusted for:
# *   date = NA (population-level)

mf2 <- glmmTMB(catch_kg ~
                 treatment +
                 offset(log(n_nets)) +
                 (1 | date),
               dat, family = lognormal(link = "log"))
summary(mf2)
ggpredict(mf2, "treatment", condition = c(n_nets = 1), back_transform = TRUE)
# treatment | Predicted |       95% CI
#'------------------------------------
# c         |      2.64 | [2.08, 3.35]
# t         |      2.82 | [2.19, 3.63]

mf3 <- glmmTMB(log(catch_kg/n_nets) ~
                 treatment + 
                 (1 | date),
               dat)
summary(mf3)
ggpredict(mf3, "treatment", condition = c(n_nets = 1), back_transform = TRUE)
# treatment | Predicted |     95% CI
#'----------------------------------
# c         |      2.63 | 1.98, 3.49
# t         |      2.50 | 1.88, 3.32
# 
# Adjusted for:
#   * date = NA (population-level)